MapUtils<K, V> extension
- on
-
- Map<
K, V>
- Map<
Methods
-
containsDuplicateValues(
) → bool - Checks if a map contains duplicate values in its values by using sets
-
equals(
Object other) → bool -
sort(
int compare(MapEntry< K, V> , MapEntry<K, V> )) → Map<K, V> - Sorts the Map based on the given function and RETURNS the sorted map. (Doesn't sort in place!)
-
swap(
) → Map< V, K> - Returns a map with the keys and values swapped. If there are duplicate keys the function throws an argument error (So use with containsDuplicateValues()).
-
where(
bool func(MapEntry< K, V> mapEntry)) → Map<K, V> -
Available on Map<
Works like List.where, you put in a function that takes a MapEntry and returns a bool. This will return new Map where the above function is true.K, V> , provided by the MapUtils extension